@@ -152,6 +152,7 @@ class Renderer(base.Renderer, CategoryUtils):
     def getPositionCSSFor(self, cat, markerImage):
 	x = self.getXPosition(cat) 
 	y = self.getYPosition(cat)
+	z = 9999
 	
 	if x == -1 or y == -1:
 	    return 'display:none'
@@ -159,15 +160,18 @@ class Renderer(base.Renderer, CategoryUtils):
 	if markerImage == "++resource++collective.contentMapper.images/SmallMarker.png":
 	    x=x-4
 	    y=y-4
+	    z=9999
 	elif markerImage == "++resource++collective.contentMapper.images/MediumMarker.png":
 	    x=x-14
 	    y=y-14
+	    z=9998
 	elif markerImage == "++resource++collective.contentMapper.images/BigMarker.png":
 	    x=x-35
 	    y=y-35
+	    z=9997
 	    
 	if x != -5:
-	    return 'position:absolute; top:%spx; left:%spx;'%(y, x)
+	    return 'position:absolute; top:%spx; left:%spx; z-index:%s'%(y, x, z)
 	    
     def getTooltipPositionCSS(self, markerImage):
 	if markerImage == "++resource++collective.contentMapper.images/SmallMarker.png":
@@ -199,7 +203,8 @@ class Renderer(base.Renderer, CategoryUtils):
                 finalCategories.remove(subtracting)
         
 	if len(finalCategories) == 0:
-	    return self.context.absolute_url()
+	    #return self.context.absolute_url()
+	    return ""
 	
         for cat in finalCategories:
             query = query + "Subject%3Alist=" + cat + "&"
